//-----------------------------------------------
// Copyright 2009 Wellcome Trust Sanger Institute
// Written by Jared Simpson (js18@sanger.ac.uk)
// Released under the GPL license
//-----------------------------------------------
//
// SGACommon.h - Common definitions used in the 
// SGA programs
//

#ifndef SGACOMMON_H
#define SGACOMMON_H

// File extensions
#define OVR_EXT ".ovr"
#define HITS_EXT ".hits"
#define RMDUPHITS_EXT ".rmhits"
#define GMAPHITS_EXT ".gmhits"
#define CTN_EXT ".ctn"
#define ASQG_EXT ".asqg"
#define SA_EXT ".sa"
#define RSA_EXT ".rsa"
#define BWT_EXT ".bwt"
#define RBWT_EXT ".rbwt"
#define SAI_EXT ".sai"
#define RSAI_EXT ".rsai"
#define SSA_EXT ".ssa"
#define POPIDX_EXT ".popidx"

// Default values
#define DEFAULT_MIN_OVERLAP 45
#define DEFAULT_EXTRACT_LEN 100
#define DEFAULT_MIN_COUNT_MAX_BASE 4
#define DEFAULT_COUNT_OFFSET 1
#endif
